FileValidator class

文件校验器

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

calculateMD5(String filePath) Future<String>
计算文件MD5
calculateSHA1(String filePath) Future<String>
计算文件SHA1
calculateSHA256(String filePath) Future<String>
计算文件SHA256
verifyFileIntegrity(String filePath, String expectedHash, HashAlgorithm algorithm) Future<bool>
验证文件完整性